#ifndef _X11_OBJECT_H_
#define _X11_OBJECT_H_

#include <X11/Intrinsic.h>

#ifdef __cplusplus
extern "C" {
#endif





    extern WidgetClass objectClass;
#ifdef __cplusplus
}
#endif
#endif
